@@ -4,15 +4,21 @@ import warnings
 import numpy as np
 import scipy as sp
 from scipy.stats.distributions import chi2
-import matplotlib.pyplot as plt
-from matplotlib.patches import Circle
-from mpl_toolkits.mplot3d.art3d import (
-    Poly3DCollection,
-    Line3DCollection,
-    pathpatch_2d_to_3d,
-)
+
 from spatialmath import base
 
+try:
+    import matplotlib.pyplot as plt
+    from matplotlib.patches import Circle
+    from mpl_toolkits.mplot3d.art3d import (
+        Poly3DCollection,
+        Line3DCollection,
+        pathpatch_2d_to_3d,
+    )
+    _matplotlib_exists = True
+except ImportError:  # pragma: no cover
+    _matplotlib_exists = False
+
 """
 Set of functions to draw 2D and 3D graphical primitives using matplotlib.
 
@@ -153,16 +159,20 @@ def plot_point(pos, marker="bs", text=None, ax=None, textargs=None, **kwargs):
     else:
         handles.append(plt.plot(x, y, marker, **kwargs))
     if text is not None:
+        try:
+            xy = zip(x, y)
+        except TypeError:
+            xy = [(x, y)]
         if isinstance(text, str):
             # simple string, but might have format chars
-            for i, xy in enumerate(zip(x, y)):
-                handles.append(plt.text(xy[0], xy[1], " " + text.format(i), **textopts))
+            for i, (x, y) in enumerate(xy):
+                handles.append(plt.text(x, y, " " + text.format(i), **textopts))
         elif isinstance(text, (tuple, list)):
-            for i, xy in enumerate(zip(x, y)):
+            for i, (x, y) in enumerate(xy):
                 handles.append(
                     plt.text(
-                        xy[0],
-                        xy[1],
+                        x,
+                        y,
                         " " + text[0].format(i, *[d[i] for d in text[1:]]),
                         **textopts
                     )
@@ -170,7 +180,7 @@ def plot_point(pos, marker="bs", text=None, ax=None, textargs=None, **kwargs):
     return handles
 
 
-def plot_homline(lines, *args, ax=None, **kwargs):
+def plot_homline(lines, *args, ax=None, xlim=None, ylim=None, **kwargs):
     """
     Plot a homogeneous line using matplotlib
 
@@ -201,8 +211,10 @@ def plot_homline(lines, *args, ax=None, **kwargs):
     """
     ax = axes_logic(ax, 2)
     # get plot limits from current graph
-    xlim = np.r_[ax.get_xlim()]
-    ylim = np.r_[ax.get_ylim()]
+    if xlim is None:
+        xlim = np.r_[ax.get_xlim()]
+    if ylim is None:
+        ylim = np.r_[ax.get_ylim()]
 
     lines = base.getmatrix(lines, (None, 3))
 
@@ -374,6 +386,26 @@ def plot_box(
 
     return [r]
 
+def plot_poly(vertices, *fmt, close=False,**kwargs):
+
+    if close:
+        vertices = np.hstack((vertices, vertices[:, [0]]))
+    return _render2D(vertices, fmt=fmt, **kwargs)
+
+
+def _render2D(vertices, pose=None, filled=False, ax=None, fmt=(), **kwargs):
+
+    ax = axes_logic(ax, 2)
+    if pose is not None:
+        vertices = pose * vertices
+
+    if filled:
+        r = plt.Polygon(vertices.T, closed=True, **kwargs)
+        ax.add_patch(r)
+    else:
+        r = plt.plot(vertices[0, :], vertices[1, :], *fmt, **kwargs)
+    return r
+
 
 def circle(centre=(0, 0), radius=1, resolution=50):
     """
@@ -501,7 +533,7 @@ def plot_ellipse(
     resolution=40,
     inverted=False,
     ax=None,
-    filled=None,
+    filled=False,
     **kwargs
 ):
     """
@@ -556,7 +588,6 @@ def plot_ellipse(
 
 # =========================== 3D shapes =================================== #
 
-
 def sphere(radius=1, centre=(0, 0, 0), resolution=50):
     """
     Points on a sphere
@@ -572,12 +603,14 @@ def sphere(radius=1, centre=(0, 0, 0), resolution=50):
 
     :seealso: :func:`plot_sphere`, :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
     """
-    u = np.linspace(0.0, 2.0 * np.pi, resolution)
-    v = np.linspace(0.0, np.pi, resolution)
+    theta_range = np.linspace(0, np.pi, resolution)
+    phi_range = np.linspace(-np.pi, np.pi, resolution)
 
-    x = radius * np.outer(np.cos(u), np.sin(v)) + centre[0]
-    y = radius * np.outer(np.sin(u), np.sin(v)) + centre[1]
-    z = radius * np.outer(np.ones_like(u), np.cos(v)) + centre[2]
+    Phi, Theta = np.meshgrid(phi_range, theta_range)
+
+    x = radius * np.sin(Theta) * np.cos(Phi)
+    y = radius * np.sin(Theta) * np.sin(Phi)
+    z = radius * np.cos(Theta)
 
     return (x, y, z)
 
@@ -613,9 +646,8 @@ def plot_sphere(radius, centre=(0, 0, 0), pose=None, resolution=50, ax=None, **k
     .. runblock:: pycon
 
         >>> from spatialmath.base import plot_sphere
-        >>> plot_sphere(1, 'r')   # red sphere wireframe
-        >>> plot_sphere(1, centre=(1,1,1), filled=True, facecolor='b')
-
+        >>> plot_sphere(radius=1, color='r')   # red sphere wireframe
+        >>> plot_sphere(radius=1, centre=(1,1,1), filled=True, facecolor='b')
 
     :seealso: :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
     """
@@ -626,17 +658,6 @@ def plot_sphere(radius, centre=(0, 0, 0), pose=None, resolution=50, ax=None, **k
     handles = []
     for c in centre.T:
         X, Y, Z = sphere(centre=c, radius=radius, resolution=resolution)
-
-        if pose is not None:
-            xc = X.reshape((-1,))
-            yc = Y.reshape((-1,))
-            zc = Z.reshape((-1,))
-            xyz = np.array((xc, yc, zc))
-            xyz = pose * xyz
-            X = xyz[0, :].reshape(x.shape)
-            Y = xyz[1, :].reshape(y.shape)
-            Z = xyz[2, :].reshape(z.shape)
-
         handles.append(_render3D(ax, X, Y, Z, **kwargs))
 
     return handles
@@ -731,7 +752,7 @@ def plot_ellipsoid(
     ``plot_ellipse(E)`` draws the ellipsoid defined by :math:`x^T \mat{E} x = 0`
     on the current plot.
 
-    Example:
+    Example::
 
           H = plot_ellipse(diag([1 2]), [3 4]', 'r'); % draw red ellipse
           plot_ellipse(diag([1 2]), [5 6]', 'alter', H); % move the ellipse
@@ -765,8 +786,8 @@ def plot_cylinder(
     """
     Plot a cylinder using matplotlib
 
-    :param radius: radius of sphere, defaults to 1
-    :type radius: float, optional
+    :param radius: radius of sphere
+    :type radius: float
     :param height: height of cylinder in the z-direction
     :type height: float or array_like(2)
     :param resolution: number of points on circumferece, defaults to 50
@@ -816,6 +837,79 @@ def plot_cylinder(
 
     return handles
 
+def plot_cone(
+    radius,
+    height,
+    resolution=50,
+    flip=False,
+    centre=(0, 0, 0),
+    ends=False,
+    ax=None,
+    filled=False,
+    **kwargs
+):
+    """
+    Plot a cone using matplotlib
+
+    :param radius: radius of cone at open end
+    :type radius: float
+    :param height: height of cone in the z-direction
+    :type height: float
+    :param resolution: number of points on circumferece, defaults to 50
+    :type resolution: int, optional
+    :param flip: cone faces upward, defaults to False
+    :type flip: bool, optional
+
+    :param pose: pose of cone, defaults to None
+    :type pose: SE3, optional
+    :param ax: axes to draw into, defaults to None
+    :type ax: Axes3D, optional
+    :param filled: draw filled polygon, else wireframe, defaults to False
+    :type filled: bool, optional
+    :param kwargs: arguments passed to ``plot_wireframe`` or ``plot_surface``
+
+    :return: matplotlib objects
+    :rtype: list of matplotlib object types
+
+    The axis of the cone is parallel to the z-axis and it is drawn pointing
+    down. The point is at z=0 and the open end at z= ``height``.  If ``flip`` is
+    True then the cone faces upwards, the point is at z= ``height`` and the open
+    end at z=0.
+
+    The cylinder can be positioned by setting ``centre``, or positioned
+    and orientated by setting ``pose``.
+
+    :seealso: :func:`~matplotlib.pyplot.plot_surface`, :func:`~matplotlib.pyplot.plot_wireframe`
+    """
+    ax = axes_logic(ax, 3)
+    
+    # https://stackoverflow.com/questions/26874791/disconnected-surfaces-when-plotting-cones
+    # Set up the grid in polar coords
+    theta = np.linspace(0, 2 * np.pi, resolution)
+    r = np.linspace(0, radius, resolution)
+    T, R = np.meshgrid(theta, r)
+
+    # Then calculate X, Y, and Z
+    X = R * np.cos(T) + centre[0]
+    Y = R * np.sin(T) + centre[1]
+    Z = np.sqrt(X**2 + Y**2) / radius * height + centre[2]
+    if flip:
+        Z = height - Z
+
+    handles = []
+    handles.append(_render3D(ax, X, Y, Z, filled=filled, **kwargs))
+    handles.append(_render3D(ax, X, (2 * centre[1] - Y), Z, filled=filled, **kwargs))
+
+    if ends and kwargs.get("filled", default=False):
+        floor = Circle(centre[:2], radius, **kwargs)
+        handles.append(ax.add_patch(floor))
+        pathpatch_2d_to_3d(floor, z=height[0], zdir="z")
+
+        ceiling = Circle(centre[:2], radius, **kwargs)
+        handles.append(ax.add_patch(ceiling))
+        pathpatch_2d_to_3d(ceiling, z=height[1], zdir="z")
+
+    return handles
 
 def plot_cuboid(
     sides=[1, 1, 1], centre=(0, 0, 0), pose=None, ax=None, filled=False, **kwargs
@@ -928,13 +1022,19 @@ def _axes_dimensions(ax):
     """
     classname = ax.__class__.__name__
 
-    if classname == "Axes3DSubplot":
+    if classname in ("Axes3DSubplot", "Animate"):
         return 3
-    elif classname == "AxesSubplot":
+    elif classname in ("AxesSubplot", "Animate2"):
         return 2
 
+def axes_get_limits(ax):
+    return np.r_[ax.get_xlim(), ax.get_ylim()]
 
-def axes_logic(ax, dimensions, projection="ortho"):
+def axes_get_scale(ax):
+    limits = axes_get_limits(ax)
+    return max(abs(limits[1] - limits[0]), abs(limits[3] - limits[2]))
+
+def axes_logic(ax, dimensions, projection="ortho", autoscale=True):
     """
     Axis creation logic
 
@@ -955,6 +1055,10 @@ def axes_logic(ax, dimensions, projection="ortho"):
 
     Used by all plot_xxx() functions in this module.
     """
+
+    if not _matplotlib_exists:
+        raise NotImplementedError("Matplotlib is not installed: pip install matplotlib")
+
     # print(f"new axis logic ({dimensions}D): ", end='')
     if ax is None:
         # no axes passed in, find out what's happening
@@ -976,7 +1080,7 @@ def axes_logic(ax, dimensions, projection="ortho"):
         # axis was given
 
         if _axes_dimensions(ax) == dimensions:
-            print("use existing axes")
+            #print("use existing axes")
             return ax
         # mismatch in dimensions, create new axes
     # print('create new axes')
@@ -984,12 +1088,14 @@ def axes_logic(ax, dimensions, projection="ortho"):
     # no axis specified
     if dimensions == 2:
         ax = plt.axes()
+        if autoscale:
+            ax.autoscale()
     else:
         ax = plt.axes(projection="3d", proj_type=projection)
     return ax
 
 
-def plotvol2(dim, ax=None, equal=True, grid=False):
+def plotvol2(dim, ax=None, equal=True, grid=False, labels=True):
     """
     Create 2D plot area
 
@@ -1006,23 +1112,35 @@ def plotvol2(dim, ax=None, equal=True, grid=False):
         * [A,B], A:B x A:B
         * [A,B,C,D], A:B x C:D
 
+    ==================  ======  ======
+    input               xrange  yrange
+    ==================  ======  ======
+    A (scalar)          -A:A    -A:A  
+    [A, B]              A:B     A:B   
+    [A, B, C, D, E, F]  A:B     C:D   
+    ==================  ======  ======
+
     :seealso: :func:`plotvol3`, :func:`expand_dims`
     """
     dims = expand_dims(dim, 2)
     if ax is None:
         ax = plt.subplot()
     ax.axis(dims)
-    ax.set_xlabel("X")
-    ax.set_ylabel("Y")
+    if labels:
+        ax.set_xlabel("X")
+        ax.set_ylabel("Y")
 
     if equal:
         ax.set_aspect("equal")
     if grid:
         ax.grid(True)
+
+    # signal to related functions that plotvol set the axis limits
+    ax._plotvol = True
     return ax
 
 
-def plotvol3(dim=None, ax=None, equal=True, grid=False, projection="ortho"):
+def plotvol3(dim=None, ax=None, equal=True, grid=False, labels=True, projection="ortho"):
     """
     Create 3D plot volume
 
@@ -1035,9 +1153,13 @@ def plotvol3(dim=None, ax=None, equal=True, grid=False, projection="ortho"):
 
     Initialize axes with dimensions given by ``dim`` which can be:
 
-        * A (scalar), -A:A x -A:A x -A:A
-        * [A,B], A:B x A:B x A:B
-        * [A,B,C,D,E,F], A:B x C:D x E:F
+    ==================  ======  ======  =======
+    input               xrange  yrange  zrange
+    ==================  ======  ======  =======
+    A (scalar)          -A:A    -A:A    -A:A
+    [A, B]              A:B     A:B     A:B
+    [A, B, C, D, E, F]  A:B     C:D     E:F
+    ==================  ======  ======  =======
 
     :seealso: :func:`plotvol2`, :func:`expand_dims`
     """
@@ -1051,9 +1173,10 @@ def plotvol3(dim=None, ax=None, equal=True, grid=False, projection="ortho"):
         ax.set_xlim3d(dims[0], dims[1])
         ax.set_ylim3d(dims[2], dims[3])
         ax.set_zlim3d(dims[4], dims[5])
-        ax.set_xlabel("X")
-        ax.set_ylabel("Y")
-        ax.set_zlabel("Z")
+        if labels:
+            ax.set_xlabel("X")
+            ax.set_ylabel("Y")
+            ax.set_zlabel("Z")
 
     if equal:
         try:
@@ -1065,15 +1188,19 @@ def plotvol3(dim=None, ax=None, equal=True, grid=False, projection="ortho"):
             )
     if grid:
         ax.grid(True)
+
+    # signal to related functions that plotvol set the axis limits
+    ax._plotvol = True
     return ax
 
 
 def expand_dims(dim=None, nd=2):
-    """[summary]
+    """
+    Expact compact axis dimensions
 
-    :param dim: [description], defaults to None
-    :type dim: [type], optional
-    :param nd: [description], defaults to 2
+    :param dim: dimensions, defaults to None
+    :type dim: scalar, array_like(2), array_like(4), array_like(6), optional
+    :param nd: number of axes dimensions, defaults to 2
     :type nd: int, optional
     :raises ValueError: bad arguments
     :return: 2d or 3d dimensions vector
@@ -1097,7 +1224,7 @@ def expand_dims(dim=None, nd=2):
         if len(dim) == 1:
             return np.r_[-dim, dim, -dim, dim]
         elif len(dim) == 2:
-            return np.r_[-dim[0], dim[0], -dim[1], dim[1]]
+            return np.r_[dim[0], dim[1], dim[0], dim[1]]
         elif len(dim) == 4:
             return dim
         else:
@@ -1147,3 +1274,4 @@ if __name__ == "__main__":
             / "test_graphics.py"
         ).read()
     )  # pylint: disable=exec-used
+
