@@ -39,7 +39,7 @@ b = np.r_[-5.0, 4.0, 3.0]
 R = base.eul2r(0.1, 0.2, 0.3)
 """
 table.rule()
-from spatialmath.base import r2q, r2q_old
+from spatialmath.base import r2q #, r2q_old
 
 
 t = timeit.timeit(stmt="q = r2q(R)", setup=setup, number=N)
@@ -76,8 +76,15 @@ result("base.norm(R6)", t)
 
 t = timeit.timeit(stmt="a = np.linalg.norm(s3)", setup=setup, number=N)
 result("np.norm(R3)", t)
+
 t = timeit.timeit(stmt="a = base.norm(s3)", setup=setup, number=N)
 result("base.norm(R3)", t)
 
+t = timeit.timeit(stmt="a = np.isclose(s, s)", setup=setup, number=N)
+result("isclose(s,s)", t)
+
+t = timeit.timeit(stmt="a = base.iszerovec(s-s)", setup=setup, number=N)
+result("base.iszerovec(s-s)", t)
+
 
 table.print()
