@@ -14,7 +14,7 @@ _eps = np.finfo(np.float64).eps
 
 # ======================================================================== #
 
-class Plane:
+class Plane3:
     r"""
     Create a plane object from linear coefficients
     
@@ -115,6 +115,21 @@ class Plane:
         """
         return abs(np.dot(self.n, p) - self.d) < tol
     
+    def plot(self, bounds=None, ax=None, **kwargs):
+        ax = base.axes_logic(ax, 3)
+        if bounds is None:
+            bounds = np.r_[ax.get_xlim(), ax.get_ylim(), ax.get_zlim()]
+
+        # X, Y = np.meshgrid(bounds[0: 2], bounds[2: 4])
+        # Z = -(X * self.plane[0] + Y * self.plane[1] + self.plane[3]) / self.plane[2]
+
+        X, Y = np.meshgrid(np.linspace(bounds[0], bounds[1], 50), 
+        np.linspace(bounds[2], bounds[3], 50))
+        Z = -(X * self.plane[0] + Y * self.plane[1] + self.plane[3]) / self.plane[2]
+        Z[Z < bounds[4]] = np.nan
+        Z[Z > bounds[5]] = np.nan
+        ax.plot_surface(X, Y, Z, **kwargs)
+
     def __str__(self):
         """
         
@@ -126,7 +141,8 @@ class Plane:
 
 # ======================================================================== #
 
-class Plucker(BasePoseList):
+
+class Line3(BasePoseList):
     """
     Plucker coordinate class
     
@@ -251,8 +267,8 @@ class Plucker(BasePoseList):
     def isvalid(x, check=False):
         return x.shape == (6,)
 
-    @staticmethod
-    def TwoPoints(P=None, Q=None):
+    @classmethod
+    def TwoPoints(cls, P=None, Q=None):
         """
         Create Plucker line object from two 3D points
         
@@ -274,10 +290,10 @@ class Plucker(BasePoseList):
         # compute direction and moment
         w = P - Q
         v = np.cross(w, P)
-        return Plucker(np.r_[v, w])
+        return cls(np.r_[v, w])
     
-    @staticmethod
-    def TwoPlanes(pi1, pi2):
+    @classmethod
+    def TwoPlanes(cls, pi1, pi2):
         r"""
         Create Plucker line from two planes
                 
@@ -297,17 +313,19 @@ class Plucker(BasePoseList):
         :seealso: Plucker, Plucker.PQ, Plucker.PointDir
         """
 
-        if not isinstance(pi1, Plane):
-            pi1 = Plane(base.getvector(pi1, 4))
-        if not isinstance(pi2, Plane):
-            pi2 = Plane(base.getvector(pi2, 4))
+        # TODO inefficient to create 2 temporary planes
+
+        if not isinstance(pi1, Plane3):
+            pi1 = Plane3(base.getvector(pi1, 4))
+        if not isinstance(pi2, Plane3):
+            pi2 = Plane3(base.getvector(pi2, 4))
         
         w = np.cross(pi1.n, pi2.n)
         v = pi2.d * pi1.n - pi1.d * pi2.n
-        return Plucker(np.r_[v, w])
+        return cls(np.r_[v, w])
 
-    @staticmethod
-    def PointDir(point, dir):
+    @classmethod
+    def PointDir(cls, point, dir):
         """
         Create Plucker line from point and direction
         
@@ -327,7 +345,7 @@ class Plucker(BasePoseList):
         p = base.getvector(point, 3)
         w = base.getvector(dir, 3)
         v = np.cross(w, p)
-        return Plucker(np.r_[v, w])
+        return cls(np.r_[v, w])
     
     def append(self, x):
         """
@@ -418,12 +436,20 @@ class Plucker(BasePoseList):
         ``M = line.skew()`` is the Plucker matrix, a 4x4 skew-symmetric matrix
         representation of the line.
 
-        Notes:
+        .. math::
+
+            \sk{L} = \begin{bmatrix} 0 & v_z & -v_y & \omega_x \\
+                -v_z & 0 & v_x & \omega_y \\
+                v_y & -v_x & 0 & \omega_z \\
+                -\omega_x & -\omega_y & -\omega_z & 0 \end{bmatrix}
+
+        .. note::
             
-         - For two homogeneous points P and Q on the line, :math:`PQ^T-QP^T` is also skew
-           symmetric.
-         - The projection of Plucker line by a perspective camera is a homogeneous line (3x1)
-           given by :math:`\vee C M C^T` where :math:`C \in \mathbf{R}^{3 \times 4}` is the camera matrix.
+         - For two homogeneous points P and Q on the line, :math:`PQ^T-QP^T` is
+           also skew symmetric.
+         - The projection of Plucker line by a perspective camera is a
+           homogeneous line (3x1) given by :math:`\vee C M C^T` where :math:`C
+           \in \mathbf{R}^{3 \times 4}` is the camera matrix.
         """
         
         v = self.v
@@ -689,6 +715,31 @@ class Plucker(BasePoseList):
         return l
 
     def closest_to_line(self, line):
+        """
+        Closest point between two lines
+
+        :param line: second line
+        :type line: Plucker
+        :return: nearest points and distance between lines at those points
+        :rtype: ndarray(3,N), ndarray(N)
+
+        Finds the point on the first line closest to the second line, as well
+        as the minimum distance between the lines.
+
+        For two sets of lines, of equal size, return an array of closest points
+        and distances.
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> from spatialmath import Plucker
+            >>> line1 = Plucker.TwoPoints([1, 1, 0], [1, 1, 1])
+            >>> line2 = Plucker.TwoPoints([0, 0, 0], [2, 3, 5])
+            >>> line1.closest_to_line(line2)
+
+        :reference: `Plucker coordinates <https://web.cs.iastate.edu/~cs577/handouts/plucker-coordinates.pdf>`_
+        """
         # point on line closest to another line
         # https://web.cs.iastate.edu/~cs577/handouts/plucker-coordinates.pdf
         # but (20) (21) is the negative of correct answer
@@ -700,10 +751,11 @@ class Plucker(BasePoseList):
             w1 = line1.w
             v2 = line2.v
             w2 = line2.w
-            p1 = (np.cross(v1, np.cross(w2, np.cross(w1, w2))) - np.dot(v2, np.cross(w1, w2)) * w1) \
-                    / np.sum(np.cross(w1, w2) ** 2)
-            p2 = (np.cross(-v2, np.cross(w1, np.cross(w1, w2))) + np.dot(v1, np.cross(w1, w2)) * w2) \
-                    / np.sum(np.cross(w1, w2) ** 2)
+            with np.errstate(divide='ignore', invalid='ignore'):
+                p1 = (np.cross(v1, np.cross(w2, np.cross(w1, w2))) - np.dot(v2, np.cross(w1, w2)) * w1) \
+                        / np.sum(np.cross(w1, w2) ** 2)
+                p2 = (np.cross(-v2, np.cross(w1, np.cross(w1, w2))) + np.dot(v1, np.cross(w1, w2)) * w2) \
+                        / np.sum(np.cross(w1, w2) ** 2)
 
             p.append(p1)
             dist.append(np.linalg.norm(p1 - p2))
@@ -722,18 +774,18 @@ class Plucker(BasePoseList):
         :param l2: An arbitrary 3D point
         :type l2: 3-element array_like
         :return: Point on the line and distance to line
-        :rtype: collections.namedtuple
+        :rtype: ndarray(3), float
 
-        - ``line.closest(x).p`` is the coordinate of a point on the line that is
-          closest to ``x``.
+        Find the point on the line closest to ``x`` as well as the distance
+        at that closest point.
 
-        - ``line.closest(x).d`` is the distance between the point on the line and ``x``.
-        
-        The return value is a named tuple with elements:
-            
-            - ``.p`` for the point on the line as a numpy.ndarray, shape=(3,)
-            - ``.d`` for the distance to the point from ``x``
-            - ``.lam`` the `lambda` value for the point on the line.
+        Example:
+
+        .. runblock:: pycon
+
+            >>> from spatialmath import Plucker
+            >>> line1 = Plucker.TwoPoints([0, 0, 0], [2, 2, 3])
+            >>> line1.closest_to_point([1, 1, 1])
 
         :seealso: Plucker.point
         """
@@ -746,7 +798,7 @@ class Plucker(BasePoseList):
         p = self.point(lam).flatten()  # is the closest point on the line
         d = np.linalg.norm( x - p)
         
-        return namedtuple('closest', 'p d lam')(p, d, lam)
+        return p, d
     
     
     def commonperp(self, l2):  # pylint: disable=no-self-argument
@@ -775,7 +827,7 @@ class Plucker(BasePoseList):
             v = np.cross(l1.v, l2.w) - np.cross(l2.v, l1.w) + \
                 (l1 * l2) * np.dot(l1.w, l2.w) * base.unitvec(np.cross(l1.w, l2.w))
             
-        return Plucker(v, w)
+        return self.__class__(v, w)
 
 
     def __mul__(self, right):  # pylint: disable=no-self-argument
@@ -799,7 +851,7 @@ class Plucker(BasePoseList):
         :seealso: Plucker.__rmul__
         """
         left = self
-        if isinstance(right, Plucker):
+        if isinstance(right, Line3):
             # reciprocal product
             return np.dot(left.uw, right.v) + np.dot(right.uw, left.v)
         else:
@@ -826,7 +878,7 @@ class Plucker(BasePoseList):
             A = np.r_[ np.c_[left.R,          base.skew(-left.t) @ left.R],
                        np.c_[np.zeros((3,3)), left.R]
                         ]
-            return Plucker( A @ right.vec)  # premultiply by SE3
+            return self.__class__( A @ right.vec)  # premultiply by SE3
         else:
             raise ValueError('bad arguments')
 
@@ -871,8 +923,8 @@ class Plucker(BasePoseList):
         # Note that this is in homogeneous coordinates.
         #    intersection of plane (n,p) with the line (v,p)
         #    returns point and line parameter
-        if not isinstance(plane, Plane):
-            plane = Plane(base.getvector(plane, 4))
+        if not isinstance(plane, Plane3):
+            plane = Plane3(base.getvector(plane, 4))
             
         den = np.dot(self.w, plane.n)
         
@@ -937,7 +989,7 @@ class Plucker(BasePoseList):
             I = np.eye(3,3)
             p = [0, 0, 0]
             p[i] = bounds[face]
-            plane = Plane.PN(n=I[:,i], p=p)
+            plane = Plane3.PN(n=I[:,i], p=p)
             
             # find where line pierces the plane
             try:
@@ -1121,13 +1173,24 @@ See also Twist.char.
         
     # Static factory methods for constructors from exotic representations
 
+class Plucker(Line3):
 
+    def __init__(self, v=None, w=None):
+        import warnings
+
+        warnings.warn('use Line class instead', DeprecationWarning)
+        super().__init__(v, w)
     
 if __name__ == '__main__':   # pragma: no cover
 
     import pathlib
     import os.path
-    
-    a = SE3.Exp([2,0,0,0,0,0])
 
-    exec(open(pathlib.Path(__file__).parent.parent.absolute() / "tests" / "test_geom3d.py").read())  # pylint: disable=exec-used
\ No newline at end of file
+    a = Plane3([0.1, -1, -1, 2])
+    base.plotvol3(5)
+    a.plot(color='r', alpha=0.3)
+    plt.show(block=True)
+    
+    # a = SE3.Exp([2,0,0,0,0,0])
+
+    # exec(open(pathlib.Path(__file__).parent.parent.absolute() / "tests" / "test_geom3d.py").read())  # pylint: disable=exec-used
\ No newline at end of file
