@@ -6,7 +6,7 @@ import numpy as np
 
 from spatialmath.pose3d import SO3, SE3
 from spatialmath.pose2d import SE2
-from spatialmath.geom3d import Plucker
+from spatialmath.geom3d import Line3
 import spatialmath.base as base
 from spatialmath.baseposelist import BasePoseList
 
@@ -632,6 +632,81 @@ class Twist3(BaseTwist):
         """
         return cls([np.r_[0,0,0,0,0,x] for x in base.getunit(theta, unit=unit)])
 
+    @classmethod
+    def Tx(cls, x):
+        """
+        Create a new 3D twist for pure translation along the X-axis
+
+        :param x: translation distance along the X-axis
+        :type x: float
+        :return: 3D twist vector
+        :rtype: Twist3 instance
+
+        `Twist3.Tx(x)` is an se(3) translation of ``x`` along the x-axis
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> Twist3.Tx(2)
+            >>> Twist3.Tx([2,3])
+
+
+        :seealso: :func:`~spatialmath.base.transforms3d.transl`
+        :SymPy: supported
+        """
+        return cls([np.r_[_x,0,0,0,0,0] for _x in base.getvector(x)], check=False)
+
+
+    @classmethod
+    def Ty(cls, y):
+        """
+        Create a new 3D twist for pure translation along the Y-axis
+
+        :param y: translation distance along the Y-axis
+        :type y: float
+        :return: 3D twist vector
+        :rtype: Twist3 instance
+
+        `Twist3.Ty(y) is an se(3) translation of ``y`` along the y-axis
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> Twist3.Ty(2)
+            >>> Twist3.Ty([2, 3])
+
+
+        :seealso: :func:`~spatialmath.base.transforms3d.transl`
+        :SymPy: supported
+        """
+        return cls([np.r_[0,_y,0,0,0,0] for _y in base.getvector(y)], check=False)
+
+    @classmethod
+    def Tz(cls, z):
+        """
+        Create a new 3D twist for pure translation along the Z-axis
+
+        :param z: translation distance along the Z-axis
+        :type z: float
+        :return: 3D twist vector
+        :rtype: Twist3 instance
+
+        `Twist3.Tz(z)` is an se(3) translation of ``z`` along the z-axis
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> Twist3.Tz(2)
+            >>> Twist3.Tz([2, 3])
+
+        :seealso: :func:`~spatialmath.base.transforms3d.transl`
+        :SymPy: supported
+        """
+        return cls([np.r_[0,0,_z,0,0,0] for _z in base.getvector(z)], check=False)
+
     @classmethod
     def Rand(cls, *, xrange=(-1, 1), yrange=(-1, 1), zrange=(-1, 1), N=1):  # pylint: disable=arguments-differ
         """
@@ -814,7 +889,7 @@ class Twist3(BaseTwist):
         Line of action of 3D twist as a Plucker line
 
         :return: the 3D line of action
-        :rtype: Plucker instance
+        :rtype: Line instance
 
         ``X.line()`` is a Plucker object representing the line of the twist axis.
 
@@ -827,7 +902,7 @@ class Twist3(BaseTwist):
             >>> S = Twist3(T)
             >>> S.line()
         """
-        return Plucker([Plucker(-tw.v - tw.pitch() * tw.w, tw.w) for tw in self])
+        return Line3([Line3(-tw.v - tw.pitch() * tw.w, tw.w) for tw in self])
 
     def pole(self):
         """
@@ -873,7 +948,7 @@ class Twist3(BaseTwist):
         """
         return base.norm(self.w)
 
-    def exp(self, theta=None, units='rad'):
+    def exp(self, theta=None, unit='rad'):
         """
         Exponentiate a 3D twist
 
@@ -906,13 +981,13 @@ class Twist3(BaseTwist):
 
         :seealso: :func:`spatialmath.base.trexp`
         """
-        if units != 'rad' and self.isprismatic:
+        if unit != 'rad' and self.isprismatic:
             print('Twist3.exp: using degree mode for a prismatic twist')
 
         if theta is None:
             theta = 1
         else:
-            theta = base.getunit(theta, units)
+            theta = base.getunit(theta, unit)
 
         if base.isscalar(theta):
             # theta is a scalar
@@ -1346,14 +1421,14 @@ class Twist2(BaseTwist):
         else:
             return [base.skewa(x.S) for x in self]
 
-    def exp(self, theta=None, units='rad'):
+    def exp(self, theta=None, unit='rad'):
         r"""
         Exponentiate a 2D twist
 
         :param theta: rotation magnitude, defaults to None
         :type theta: float, optional
-        :param units: rotational units, defaults to 'rad'
-        :type units: str, optional
+        :param unit: rotational units, defaults to 'rad'
+        :type unit: str, optional
         :return: SE(2) matrix
         :rtype: SE2 instance
 
@@ -1380,13 +1455,13 @@ class Twist2(BaseTwist):
         :seealso: :func:`spatialmath.base.trexp2`
         """
 
-        if units != 'rad' and self.isprismatic:
+        if unit != 'rad' and self.isprismatic:
             print('Twist3.exp: using degree mode for a prismatic twist')
 
         if theta is None:
             theta = 1
         else:
-            theta = base.getunit(theta, units)
+            theta = base.getunit(theta, unit)
 
         if base.isscalar(theta):
             return SE2(base.trexp2(self.S * theta))
@@ -1408,8 +1483,8 @@ class Twist2(BaseTwist):
         .. runblock:: pycon
 
             >>> from spatialmath import SE3, Twist3
-            >>> T = SE3(1, 2, 3) * SE3.Rx(0.3)
-            >>> S = Twist3(T)
+            >>> T = SE2(1, 2, 0.3)
+            >>> S = Twist2(T)
             >>> S.pole()
         """
         p = np.cross(np.r_[0, 0, self.w], np.r_[self.v, 0]) / self.theta()
@@ -1420,8 +1495,17 @@ class Twist2(BaseTwist):
         """
         Unit twist
 
-        - ``S.unit()`` is a Twist3 object representing a unit twist aligned with the
-        Twist ``S``.
+        - ``S.unit()`` is a Twist2 object representing a unit twist aligned with the
+          Twist ``S``.
+
+        Example:
+        
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3, Twist3
+            >>> T = SE2(1, 2, 0.3)
+            >>> S = Twist2(T)
+            >>> S.unit()
         """
         if base.iszerovec(self.w):
             # rotational twist
@@ -1433,14 +1517,77 @@ class Twist2(BaseTwist):
     @property
     def ad(self):
         """
-        Twist3.ad Logarithm of adjoint
+        Twist2.ad Logarithm of adjoint
 
         - ``S.ad()`` is the logarithm of the adjoint matrix of the corresponding
-        homogeneous transformation.
+          homogeneous transformation.
+
+        Example:
+        
+        .. runblock:: pycon
+
+            >>> from spatialmath import SE3, Twist3
+            >>> T = SE2(1, 2, 0.3)
+            >>> S = Twist2(T)
+            >>> S.unit()
 
         :seealso: SE3.Ad.
         """
-        return np.array([base.skew(self.w), base.skew(self.v), [np.zeros((3, 3)), base.skew(self.w)]])
+        return np.array([
+                    [base.skew(self.w), base.skew(self.v)], 
+                    [np.zeros((3, 3)), base.skew(self.w)]
+                ])
+
+    @classmethod
+    def Tx(cls, x):
+        """
+        Create a new 2D twist for pure translation along the X-axis
+
+        :param x: translation distance along the X-axis
+        :type x: float
+        :return: 2D twist vector
+        :rtype: Twist2 instance
+
+        `Twist2.Tx(x)` is an se(2) translation of ``x`` along the x-axis
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> Twist2.Tx(2)
+            >>> Twist2.Tx([2,3])
+
+
+        :seealso: :func:`~spatialmath.base.transforms2d.transl2`
+        :SymPy: supported
+        """
+        return cls([np.r_[_x,0,0] for _x in base.getvector(x)], check=False)
+
+
+    @classmethod
+    def Ty(cls, y):
+        """
+        Create a new 2D twist for pure translation along the Y-axis
+
+        :param y: translation distance along the Y-axis
+        :type y: float
+        :return: 2D twist vector
+        :rtype: Twist2 instance
+
+        `Twist2.Ty(y) is an se(2) translation of ``y`` along the y-axis
+
+        Example:
+
+        .. runblock:: pycon
+
+            >>> Twist2.Ty(2)
+            >>> Twist2.Ty([2, 3])
+
+
+        :seealso: :func:`~spatialmath.base.transforms2d.transl2`
+        :SymPy: supported
+        """
+        return cls([np.r_[0,_y,0] for _y in base.getvector(y)], check=False)
 
     def __mul__(left, right):  # lgtm[py/not-named-self] pylint: disable=no-self-argument
         """
